paidiverpy.models.convert_params
================================

.. py:module:: paidiverpy.models.convert_params

.. autoapi-nested-parse::

   Convert layer parameters models.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.convert_params.BitParams
   paidiverpy.models.convert_params.ToParams
   paidiverpy.models.convert_params.NormalizeParams
   paidiverpy.models.convert_params.ResizeParams
   paidiverpy.models.convert_params.CropParams


Module Contents
---------------

.. py:class:: BitParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   This class contains the parameters for the bit conversion.
















   ..
       !! processed by numpydoc !!

.. py:class:: ToParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   This class contains the parameters for the channel conversion.
















   ..
       !! processed by numpydoc !!

.. py:class:: NormalizeParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   This class contains the parameters for the image normalization.
















   ..
       !! processed by numpydoc !!

.. py:class:: ResizeParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   This class contains the parameters for the image resizing.
















   ..
       !! processed by numpydoc !!

.. py:class:: CropParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   This class contains the parameters for the image cropping.
















   ..
       !! processed by numpydoc !!

